<?php
/**
 * @file Guestbook.php 
 * @desc communication between flash and php (mysql)
 *
 * @update : -
 *
 * @author Matthieu DELOISON
 * @since 15 Juillet 2007 
 * @update 
 *
 * @version 1
 


-- 
-- Structure de la table `add_on_guestbook`
-- 

DROP TABLE IF EXISTS `add_on_guestbook`;
CREATE TABLE IF NOT EXISTS `add_on_guestbook` (
  `id` int(11) NOT NULL auto_increment,
  `pseudo` varchar(25) NOT NULL default '',
  `date` datetime NOT NULL default '0000-00-00 00:00:00',
  `website` varchar(255) NOT NULL default '',
  `message` longtext NOT NULL,
  `enable` tinyint(1) NOT NULL default '1',
  PRIMARY KEY  (`id`),
  KEY `date` (`date`)
) TYPE=MyISAM COMMENT='Add on Livre d''Or Delfiweb' AUTO_INCREMENT=1 ;
  
 */
 

class Guestbook
{

	private $oSqlConnection;
	

	/* config */
	const i_NB_MSG_BY_PAGE = 8; // number of message by page.
	const i_VALIDITE_MSG = 1; // enable new message.
	
	
	// ---------------------------------- __construct() ----------------------------------------------------------
   /**
	* @brief 
	* @param -
	*/
	public function __construct()
	{
		$this->methodTable = array
		(
			"getMessage" => array
			(
				"description" => "read the message",
				"access" => "remote",
				"arguments" => "number",
				"returns" => "array"
			),
			
			"addMessage" => array
			(
				"description" => "write a message",
				"access" => "remote",
				"arguments" => "array",
				"returns" => "array"
			)		
		);	
		//$s_homeDirectory = "/home.2/test/www/"; // PROD
		
		/* init */
		$s_homeDirectory = "../../../../../"; // TEST
		require_once ($s_homeDirectory."include/php/classes/Master.php");
		$o_Master = Master::GetInstance();
		$o_Master->newPage($s_homeDirectory);
	
		$this->oSqlConnection = new Mysql();
	}

	
	// -----------------------------------------------------------------------------------------------------------
	// ------------------------------------------- PUBLIC FUNCTIONS  ---------------------------------------------
	// -----------------------------------------------------------------------------------------------------------


	
	
	// ---------------------------------------- getMessage() ----------------------------------------------------	
	/**
	 * @brief give the messages of the guestbook.
	 * @param (integer)	number of a page.
	 * @return (array)  an array $a_MsgInfos["messages"] -- $a_MsgInfos["numpage"] -- $a_MsgInfos["nbpage"]
	 */		
	public function getMessage($i_numPage)
	{
		$a_MsgInfos = array();
		$a_MsgInfos = self::getMsgBDD($i_numPage);
									
		return $a_MsgInfos;
	}
	
	
	
	// ---------------------------------------- addMessage() ----------------------------------------------------	
	/**
	 * @brief write a message in the guestbook.
	 * @param (array)	an array who contain the informations of the new message.
	 * @return (array)  an array who contain the message of the first page $a_MsgInfos["messages"] -- $a_MsgInfos["numpage"] -- $a_MsgInfos["nbpage"]
	 */
	public function addMessage($a_objMsg)
	{
		/* Init */
		$a_MsgInfos = array();
		
		// add the mesage
		$s_message_temp = str_replace( "\r", "<br />", $a_objMsg['message'] );
		$s_message = addslashes( $s_message_temp );
		
		$s_pseudo = addslashes( $a_objMsg['pseudo'] );
		$s_website = $a_objMsg['website'];
		
		$s_sqlInsert = "INSERT INTO add_on_guestbook (pseudo, date, website, message, enable)";
		$s_sqlInsert .= " VALUES ( '$s_pseudo', NOW(), '$s_website', '$s_message', ".self::i_VALIDITE_MSG.")";
		$o_sqlResult = $this->oSqlConnection->query($s_sqlInsert);
			
		$a_MsgInfos=self::getMsgBDD(1);

		return $a_MsgInfos;
	}	
	

	// -----------------------------------------------------------------------------------------------------------
	// ------------------------------------------ PRIVATE FUNCTIONS  ---------------------------------------------
	// -----------------------------------------------------------------------------------------------------------


	// ---------------------------------------- getMsgBDD() ----------------------------------------------------	
	/**
	 * @brief read the messages in the database.
	 * @param (integer) number of the page.
	 * @return (array) an array who contain $a_MsgInfos["messages"] -- $a_MsgInfos["numpage"] -- $a_MsgInfos["nbpage"]
	 */
	private function getMsgBDD($i_numPage)
	{
		/* Init */
		$a_MsgInfos = array();
				
		$a_MsgInfos["msglist"] = array();

		$i_numPage = (integer) $i_numPage;
		
		
		/* read in database */
		$s_sqlSelect = " SELECT count( * ) as total
		FROM `add_on_guestbook`
		WHERE `enable` = 1 "; // get the total of messages.
		
		$o_sqlResult = $this->oSqlConnection->query($s_sqlSelect);
		$o_result = $this->oSqlConnection->getObject($o_sqlResult);
		$i_nbMessages = $o_result->total;
				
		// give the number of total pages.
		$i_nbPages = ceil($i_nbMessages/self::i_NB_MSG_BY_PAGE); // Arrondit au nombre suprieur
		
		// by safety
		if( $i_numPage > $i_nbPages ) $i_numPage = $i_nbPages;
		
		
		/* give the messages for the page */
		
		$i_limitBegin = self::i_NB_MSG_BY_PAGE * ($i_numPage-1);
		
		if ($i_limitBegin < 0) $i_limitBegin = 0;
		$s_sqlSelect = "SELECT pseudo, date, website, message FROM add_on_guestbook WHERE enable = 1";
		$s_sqlSelect .= " ORDER BY date DESC LIMIT ".$i_limitBegin.", ".self::i_NB_MSG_BY_PAGE;
		$o_sqlResult = $this->oSqlConnection->query($s_sqlSelect);
				
		$s_allMessages = "";
		$i_cptMsg = 0;
		while ( $o_result = $this->oSqlConnection->getObject($o_sqlResult) )
		{
			$a_OneMsg = array();
			
			$a_OneMsg["pseudo"] = $o_result->pseudo;
			$s_date = $o_result->date;
			$a_date_fr = Utils::getDateFr($s_date, NULL, 1);
			$a_OneMsg["date"] = utf8_encode($a_date_fr["date"]."  ".$a_date_fr["time"]);
			
			$a_OneMsg["website"] = $o_result->website;
			$a_OneMsg["message"] = $o_result->message;	
			
			$a_MsgInfos["msglist"][$i_cptMsg] = $a_OneMsg;
			
			$i_cptMsg++;
		}

		$a_MsgInfos["page"] = $i_numPage;
		$a_MsgInfos["total_page"] = $i_nbPages;
			
		return $a_MsgInfos;
	}


	
	// -----------------------------------------------------------------------------------------------------------
	// ----------------------------------------- Others ----------------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------


 	/**
	* @brief
	*
	* @return 
	*/
	public function __destruct() 
	{
 
 	}
	
	
	
	// ---------------------------------------- __toString() ----------------------------------------------------	
	/**
	 * @brief Returns the string representation of this instance.
	 * @usage   echo(myObject) ou print(myObject)
	 * @return  the string representation of this instance.
	 */	
	public function __toString() 
	{
		$s_classContent = "[Object ".__CLASS__."]<br />";

		foreach($this as $prop => $value) 
		{
		 	$s_classContent .= "$prop => $value <br />";
		}
		 
		return $s_classContent;
   	}
	
}
?>