<?php 

/**
 * @file Master.php
 * @desc Init the website, create header, footer, include classes
 * 
 * @author Matthieu DELOISON
 * @date 6 Octobre 2007
 * @update
 *
 *
 * @version 0.1 
 */
 
/**
 * @note : 
 * 			- this class is a singleton.	
 */
 
 /**
 * @details : 
 *		
 * @usage :
 *		
 */
class Master 
{
	
	/* constantes */
	private static $o_instance = NULL; // unique instance
	
	
	/* configuration */
	private $s_homeDirectory; 
	private $s_Domain;
	private $b_addHeader;
	private $b_addFooter;
	private $b_modeTest;
	
	
	
	// ---------------------------------- __construct() ----------------------------------------------------------
   /**
	* @brief Constructeur de la classe. vide pour l'instant.
	* @param -
	*/
	private function __construct()
	{
		$this->b_addHeader = false;
		$this->b_addFooter = false;
		$this->s_Domain = "http://www.delfiweb.com/";
		self::$o_instance = $this;
		
		// fermeture temporaire
		/*header("Status: 302 Moved Permanently");
		header("Location: http://www.delfiweb.com/maintenance.php");
		exit();*/
	}


	// -----------------------------------------------------------------------------------------------------------
	// -------------------------------------- M�thodes publiques  ------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------
	
	
	// ---------------------------------- setInit() ----------------------------------------------------------
	/**
	* @brief Set the init (header and footer is already build).
	* @param
	* @return
	*/
	public function setInit($b_value=false, $b_test=false)
	{
		$this->b_addHeader = $b_value;
		$this->b_addFooter = $b_value;
		$this->b_modeTest = $b_test;
	}
	
	
	// ---------------------------------- newPage() ----------------------------------------------------------
	/**
	* @brief Build a new page, add classes.
	* @param (string) root path
	* @return
	*/
	public function newPage( $s_Path="" )
	{
		$this->s_homeDirectory = $s_Path;
		
		/*--- on empeche le navigateur de cacher la page ---*/
		clearstatcache(); // efface les donnes php en cache
		$CachePlus = "";
		$CachePlus = ", pre-check=0, post-check=0, max-age=0";
		$now = gmdate('D, d M Y H:i:s') . ' GMT';
		header("Expires: $now");
		//header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); 
		header("Last-Modified: $now");
		header("Cache-Control: no-cache, must-revalidate".$CachePlus);
		header("Pragma: no-cache");	


		require_once($this->s_homeDirectory."include/php/classes/Mysql.php");
		require_once($this->s_homeDirectory."include/php/classes/Utils.php");
		require_once($this->s_homeDirectory."include/php/classes/Save.php");
		require_once($this->s_homeDirectory."include/php/classes/Reference.php");
		
		require_once($this->s_homeDirectory."include/php/classes/utilitaires/Debugger.php");
		
		$this->createReference();
	}
	
	
	// ---------------------------------- addHeader() ----------------------------------------------------------
	/**
	* @brief Add the header to the page.
	* @param
	* @return
	*/
	public function addHeader($s_title="Delfiweb - Ressources Flash, Framework AS2, AS3, HAXE")
	{
		$s_titlePage = utf8_encode($s_title);
		
		if($this->b_addHeader == false)
		{
			$s_homeDirectory = $this->s_homeDirectory;
			if( $this->b_modeTest==false ) require_once($this->s_homeDirectory."template/header.php");
			else require_once($this->s_homeDirectory."template/header_test.php");
			$this->b_addHeader = true;
		}
		else echo "<script type=\"text/javascript\"> document.title=('".addslashes($s_titlePage)."') </script>";
	}
	
	
	
	// ---------------------------------- addFooter() ----------------------------------------------------------
	/**
	* @brief Add the footer to the page.
	* @param
	* @return
	*/
	public function addFooter($s_pageName="Delfiweb - No Name")
	{
		if($this->b_addFooter == true) return;
		$s_homeDirectory = $this->s_homeDirectory;
		if( $this->b_modeTest==false ) require_once($this->s_homeDirectory."template/footer.php");
		else require_once($this->s_homeDirectory."template/footer_test.php");
		$this->b_addFooter = true;
	}
	
	
	// ---------------------------------- addReference() ----------------------------------------------------------
	/**
	* @brief Add the texte for referencement in google.
	* @param
	* @return
	*/
	public function addReference()
	{
		/*--- pour le r�f�rencement sur les sites fr ---*/
		require_once($this->s_homeDirectory."include/page_content/contentXML.htm");
		require_once($this->s_homeDirectory."include/page_content/referencement-fr.htm");
	}
		

	// -----------------------------------------------------------------------------------------------------------
	// --------------------------------------------- Getter ------------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------
	
	
	
	/**
	 * @brief redfinition de la m�thode __get afin de dterminer comment la classe doit ragir lorsqu'on appelle une de ses propri�t�s
	 * @param (string)	le nom de la propri�t�  retourner
	 * @return le contenu de la propri�t�
	 */
	public function __get($s_prop)
	{
		switch($s_prop)
		{
			case 'homeDir' :
				return	$this->s_homeDirectory;
			
			case 'init' : 
				return	$this->b_addHeader;
			
			case 'domain' : 
				return	$this->s_Domain;
				
			default :
				$s_message = 'la propri�t� '.$s_prop.' n\'existe pas dans la classe '.__CLASS__.'</br>'; // gnrer une erreur
				echo $s_message;
				return $s_message;
		}	
	}


	
	// -----------------------------------------------------------------------------------------------------------
	// -------------------------------------------- Setter -------------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------
	
	

	/**
	 * @brief red�finition de la m�thode __set afin de d�terminer comment la classe doit r�agir lorsqu'on appelle un de ses attributs
	 * @param (string)	le nom de la propri�t� � modifier
	 * @param (-)	la nouvelle valeur de la propri�t�
	 * @return -
	 */
	public function __set($s_prop, $value)
	{	
		switch($s_prop)
		{
			case 'homeDir' :
				$this->s_homeDirectory = $value;
				break;

			default :
				echo 'SETTER la propri�t� '.$s_prop.' n\'existe pas dans la classe '.__CLASS__.'</br>'; // g�n�rer une erreur
		}
		
	}


	// ---------------------------------- GetInstance() ----------------------------------------------------------
	/**
	* @return (Master) instance unique of Master
	*/
	public static function GetInstance() 
	{
		if ( self::$o_instance == NULL ) self::$o_instance = new Master();
		
		return self::$o_instance;
	}

		
		
	
	// -----------------------------------------------------------------------------------------------------------
	// ---------------------------------------- M�thodes priv�es  ------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------

	
	
	// ---------------------------------- createReference() ----------------------------------------------------------
	/**
	* @brief Create the texte for referencement in google.
	* @param
	* @return
	*/
	private function createReference()
	{
		/* r�f�rencement */
		$i_ref =  rand(1, 333);
		//$i_ref  = 123;
		if ( $i_ref == 123 )
		{
			$a_xmlTxt = array($this->s_homeDirectory."xml/content/fr/accueil.xml", $this->s_homeDirectory."xml/content/fr/news.xml", $this->s_homeDirectory."xml/content/fr/framework.xml", $this->s_homeDirectory."xml/content/fr/projets.xml", $this->s_homeDirectory."xml/content/fr/tutoriaux.xml"); // "xml/content/fr/contact.xml", $this->s_homeDirectory."xml/content/fr/partenaires.xml"
			
			$o_reference = new Reference($a_xmlTxt);
			
			$b_result = $o_reference->createFileHTML($this->s_homeDirectory."include/page_content/contentXML.htm");
			
			$s_adress = "contact@delfiweb.com";
			$s_subject = "Referencement automatique Delfiweb.com";
			
			if( $b_result==true )
				mail($s_adress, $s_subject, "Fichier de referencement contentXML.htm cree avec succes.");
			else
				mail($s_adress, $s_subject, "Erreur lors de la creation du fichier de referencement.");
		}
	}
	
	
	
 	// -------------------------------------------------------------------------------------------------
	// ---------------------------------------- Divers  ------------------------------------------------
	// -------------------------------------------------------------------------------------------------

	
 	/**
	* @brief Destructeur de la classe
	* Utilis� pour enregistrer des messages pour le debogage, fermer les fichier ouverts en �criture ou en lecture, r�aliser des op�rations
	* de nettoyage des objets utilis�s...
	*
	* @param 
	* @return 
	*/
	public function __destruct() 
	{
 
 	}



	/**
	 * @brief D�termine comment la classe doit r�agir lorsqu'elle est convertie en cha�ne de caract�res.
	 * @usage   echo(myObject) ou print(myObject)
	 * @return  la repr�sentation de l'objet sous forme de cha�ne.
	 */	
	public function __toString() 
	{
		
		$s_classContent = "[Object ".__CLASS__."]<br />";
		// parcours toutes les propri�t�s de la classe et les renvoie	
		foreach($this as $prop => $value) 
		{
		 	$s_classContent .= "$prop => $value <br />";
		}
		 
		return $s_classContent;
   	}

}
 
 
 

?>